using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

using WebServiceClient.FoxWebService;
using System.Net;
using System.ServiceModel;
using System.ServiceModel.Channels;

using WebServiceClient.FoxWcfService;

namespace WebServiceClient
{
    [ClassInterface(ClassInterfaceType.AutoDual)]
    [ProgId("WebServiceClient.FoxWcfServiceClient")]
    public class FoxWcfServiceClient
    {
        /// <summary>
        /// An error message set when a method returns an error result       
        /// </summary>
        public string ErrorMessage
        {
            get { return _ErrorMessage; }
            set { _ErrorMessage = value; }
        }
        private string _ErrorMessage = "";

        public FoxWcfService.FoxWcfServiceClient Proxy
        {
            get
            {
                if (this._Proxy == null)
                    this.SetProxy(null, false);
                return _Proxy;
            }
            set { _Proxy = value; }
        }
        private FoxWcfService.FoxWcfServiceClient _Proxy = null;

        /// <summary>
        /// Create an instance of the WCF Proxy and configure it
        /// Note you can pass an endpoint URL here to allow 
        /// programmatic configuration from FoxPro
        /// </summary>
        /// <param name="EndPointUrl"></param>
        public void SetProxy(string EndPointUrl, bool UseWs)
        {
            Binding binding = null;
            if (!UseWs)
            {
                if (string.IsNullOrEmpty(EndPointUrl))
                    EndPointUrl = "http://rasvista/FoxWebService/FoxWcfService.svc";
                binding = new BasicHttpBinding();
            }
            else
            {
                if (string.IsNullOrEmpty(EndPointUrl))
                    EndPointUrl = "http://rasvista/FoxWebService/FoxWcfService.svc/ws";
                binding = new WSHttpBinding();
                //binding.MessageEncoding = WSMessageEncoding.Mtom;
            }

            binding.ReceiveTimeout = TimeSpan.FromSeconds(30F);

            this._Proxy = new FoxWcfService.FoxWcfServiceClient(
                                binding,
                                new EndpointAddress(EndPointUrl));

            //this._Proxy.ClientCredentials = new NetworkCredential();
        }

        /// <summary>
        /// Echo back server status settings from FoxPro COM object
        /// </summary>
        /// <returns></returns>
        public string FoxServerStatus()
        {
            string Result = "";
            try
            {
                Result = this.Proxy.FoxServerStatus();
            }
            catch (Exception ex)
            {
                this.ErrorMessage = ex.Message;
            }

            return Result;
        }

        /// <summary>
        /// Retrieve a complex Customer object back to client
        /// </summary>
        /// <returns></returns>
        public WebServiceClient.FoxWcfService.cCustomer GetCustomer()
        {
            WebServiceClient.FoxWcfService.cCustomer Customer = null;
            try
            {
                Customer = this.Proxy.GetCustomer();
            }
            catch (Exception ex)
            {
                this.ErrorMessage = ex.Message;
            }

            return Customer;
        }
    }
}
